@@ -1,8 +1,7 @@
 package Coro::ProcessPool;
 # ABSTRACT: An asynchronous pool of perl processes
-$Coro::ProcessPool::VERSION = '0.29';
-use strict;
-use warnings;
+$Coro::ProcessPool::VERSION = '0.30';
+use common::sense;
 use Coro;
 use Coro::Countdown;
 use AnyEvent::ProcessPool;
@@ -13,6 +12,7 @@ sub new {
   my $pool = AnyEvent::ProcessPool->new(
     workers => $param{max_procs},
     limit   => $param{max_reqs},
+    include => $param{include},
   );
 
   my $self = bless {
@@ -86,7 +86,7 @@ Coro::ProcessPool - An asynchronous pool of perl processes
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
