@@ -1,9 +1,8 @@
 
 package Coro::ProcessPool::Pipeline;
 # ABSTRACT: A producer/consumer pipeline for Coro::ProcessPool
-$Coro::ProcessPool::Pipeline::VERSION = '0.29';
-use strict;
-use warnings;
+$Coro::ProcessPool::Pipeline::VERSION = '0.30';
+use common::sense;
 use Carp;
 use Coro;
 use Try::Catch;
@@ -87,7 +86,7 @@ Coro::ProcessPool::Pipeline - A producer/consumer pipeline for Coro::ProcessPool
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
